==> open-xchange-realtime-json_7.8.0.orig.tar.bz2: open-xchange-realtime-json-7.8.0/com.openexchange.realtime.json/src/com/openexchange/realtime/json/payload/converter/ThrowableToJSONConverter.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.json.payload.converter;

import org.json.JSONArray;
import org.json.JSONObject;
import com.openexchange.conversion.DataExceptionCodes;
import com.openexchange.conversion.simple.SimpleConverter;
import com.openexchange.exception.OXException;
import com.openexchange.tools.session.ServerSession;

/**
 * {@link ThrowableToJSONConverter}
 * 
 * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
 */
public class ThrowableToJSONConverter extends AbstractPOJOConverter {

    @Override
    public String getInputFormat() {
        return Throwable.class.getSimpleName();
    }

    @Override
    public Object convert(Object data, ServerSession session, SimpleConverter converter) throws OXException {
        try {
            Throwable throwable = (Throwable) data;
            String message = throwable.getMessage();
            StackTraceElement[] traceElements = throwable.getStackTrace();
            JSONObject jsonThrowable = new JSONObject();
            jsonThrowable.put("message", message);
            JSONArray stackTraceArray = stackTraceToJSON(traceElements, converter);
            jsonThrowable.put("stackTrace", stackTraceArray);
            return jsonThrowable;
        } catch (Exception e) {
            throw DataExceptionCodes.UNABLE_TO_CHANGE_DATA.create(data.toString(), e);
        }
    }

    private JSONArray stackTraceToJSON(StackTraceElement[] stackTrace, SimpleConverter converter) throws OXException {
        JSONArray stackTraceArray = new JSONArray();
        for (StackTraceElement stackTraceElement : stackTrace) {
            Object element = converter.convert(StackTraceElement.class.getSimpleName(), "json", stackTraceElement, null);
            stackTraceArray.put(element);
        }
        return stackTraceArray;
    }

}

==> open-xchange-realtime-json_7.10.0.orig.tar.bz2: open-xchange-realtime-json-7.10.0/com.openexchange.realtime.json/src/com/openexchange/realtime/json/payload/converter/ThrowableToJSONConverter.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.json.payload.converter;

import org.json.JSONArray;
import org.json.JSONObject;
import com.openexchange.conversion.DataExceptionCodes;
import com.openexchange.conversion.simple.SimpleConverter;
import com.openexchange.exception.OXException;
import com.openexchange.tools.session.ServerSession;

/**
 * {@link ThrowableToJSONConverter}
 *
 * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
 */
public class ThrowableToJSONConverter extends AbstractPOJOConverter {

    @Override
    public String getInputFormat() {
        return Throwable.class.getSimpleName();
    }

    @Override
    public Object convert(Object data, ServerSession session, SimpleConverter converter) throws OXException {
        try {
            Throwable throwable = (Throwable) data;
            String message = throwable.getMessage();
            StackTraceElement[] traceElements = throwable.getStackTrace();
            JSONObject jsonThrowable = new JSONObject();
            jsonThrowable.put("message", message);
            JSONArray stackTraceArray = stackTraceToJSON(traceElements, converter);
            jsonThrowable.put("stackTrace", stackTraceArray);
            return jsonThrowable;
        } catch (Exception e) {
            throw DataExceptionCodes.UNABLE_TO_CHANGE_DATA.create(e, data.toString());
        }
    }

    private JSONArray stackTraceToJSON(StackTraceElement[] stackTrace, SimpleConverter converter) throws OXException {
        JSONArray stackTraceArray = new JSONArray();
        for (StackTraceElement stackTraceElement : stackTrace) {
            Object element = converter.convert(StackTraceElement.class.getSimpleName(), "json", stackTraceElement, null);
            stackTraceArray.put(element);
        }
        return stackTraceArray;
    }

}
